"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = require("react");
var rnjs_1 = require("rnjs");
exports.useRN = function (source$) {
    return react_1.useMemo(function () { return source$; }, [] // eslint-disable-line react-hooks/exhaustive-deps
    );
};
exports.useRNEffect = function (source$, subscriptionFn, runWithFirstValue) {
    if (runWithFirstValue === void 0) { runWithFirstValue = true; }
    react_1.useEffect(function () {
        var s = source$.listen(runWithFirstValue, subscriptionFn);
        return function () {
            s.unsubscribe();
            source$.terminate();
        };
    }, []); // eslint-disable-line react-hooks/exhaustive-deps
};
exports.useRNValue = function (source$, runWithFirstValue) {
    if (runWithFirstValue === void 0) { runWithFirstValue = true; }
    var _a = tslib_1.__read(react_1.useState(source$.value), 2), value = _a[0], setValue = _a[1];
    exports.useRNEffect(source$, setValue, runWithFirstValue);
    return value;
};
exports.useStateAsStream = function (initialState) {
    var src$ = react_1.useMemo(function () { return rnjs_1.manual(initialState); }, [] // eslint-disable-line react-hooks/exhaustive-deps
    );
    var setter = react_1.useCallback(function (v) {
        src$.emit(v);
    }, []); // eslint-disable-line react-hooks/exhaustive-deps
    return [src$, setter];
};
exports.useEventAsStream = function () {
    var eventEmitter$ = react_1.useMemo(function () { return rnjs_1.manual(undefined); }, []);
    var fire = react_1.useCallback(function () {
        eventEmitter$.emit(undefined);
    }, []); // eslint-disable-line react-hooks/exhaustive-deps
    return [eventEmitter$, fire];
};
exports.usePropAsStream = function (prop) {
    var _a = tslib_1.__read(exports.useStateAsStream(prop), 2), value$ = _a[0], setValue = _a[1];
    react_1.useEffect(function () {
        setValue(prop);
    }, [setValue, prop]);
    return value$;
};
exports.useEffectFromProps = function (input, callback, deps) {
    react_1.useEffect(function () {
        if (input !== undefined) {
            callback(input);
        }
        // eslint-disable-next-line
    }, deps || [input, callback]);
};
exports.useStateWithResetter = function (initialState) {
    var _a = tslib_1.__read(react_1.useState(initialState), 2), state = _a[0], setState = _a[1];
    var resetState = react_1.useCallback(function () { return setState(initialState); }, [
        setState,
        initialState
    ]);
    return [state, setState, resetState];
};
exports.useStateAsStreamWithResetter = function (initialState) {
    var _a = tslib_1.__read(exports.useStateAsStream(initialState), 2), state$ = _a[0], setState = _a[1];
    var resetState = react_1.useCallback(function () { return setState(initialState); }, [
        setState,
        initialState
    ]);
    return [state$, setState, resetState];
};
//# sourceMappingURL=index.js.map